@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -11,20 +10,21 @@
 
 #include "grib_accessor_class_g1monthlydate.h"
 
-grib_accessor_class_g1monthlydate_t _grib_accessor_class_g1monthlydate{"g1monthlydate"};
+grib_accessor_class_g1monthlydate_t _grib_accessor_class_g1monthlydate{ "g1monthlydate" };
 grib_accessor_class* grib_accessor_class_g1monthlydate = &_grib_accessor_class_g1monthlydate;
 
 
-void grib_accessor_class_g1monthlydate_t::init(grib_accessor* a, const long l, grib_arguments* c){
+void grib_accessor_class_g1monthlydate_t::init(grib_accessor* a, const long l, grib_arguments* c)
+{
     grib_accessor_class_long_t::init(a, l, c);
     grib_accessor_g1monthlydate_t* self = (grib_accessor_g1monthlydate_t*)a;
-    int n                             = 0;
 
-    self->date = grib_arguments_get_name(grib_handle_of_accessor(a), c, n++);
+    self->date = grib_arguments_get_name(grib_handle_of_accessor(a), c, 0);
     a->flags |= GRIB_ACCESSOR_FLAG_READ_ONLY;
 }
 
-int grib_accessor_class_g1monthlydate_t::unpack_long(grib_accessor* a, long* val, size_t* len){
+int grib_accessor_class_g1monthlydate_t::unpack_long(grib_accessor* a, long* val, size_t* len)
+{
     grib_accessor_g1monthlydate_t* self = (grib_accessor_g1monthlydate_t*)a;
 
     long date = 0;
