@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -11,19 +10,20 @@
 
 #include "grib_accessor_class_library_version.h"
 
-grib_accessor_class_library_version_t _grib_accessor_class_library_version{"library_version"};
+grib_accessor_class_library_version_t _grib_accessor_class_library_version{ "library_version" };
 grib_accessor_class* grib_accessor_class_library_version = &_grib_accessor_class_library_version;
 
 
-int grib_accessor_class_library_version_t::unpack_string(grib_accessor* a, char* val, size_t* len){
+int grib_accessor_class_library_version_t::unpack_string(grib_accessor* a, char* val, size_t* len)
+{
     char result[30] = {0,};
-    size_t size;
+    size_t size = 0;
 
     int major    = ECCODES_MAJOR_VERSION;
     int minor    = ECCODES_MINOR_VERSION;
     int revision = ECCODES_REVISION_VERSION;
 
-    snprintf(result,  sizeof(result), "%d.%d.%d", major, minor, revision);
+    snprintf(result, sizeof(result), "%d.%d.%d", major, minor, revision);
     size = sizeof(result);
 
     if (*len < size)
@@ -35,11 +35,13 @@ int grib_accessor_class_library_version_t::unpack_string(grib_accessor* a, char*
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_library_version_t::value_count(grib_accessor* a, long* count){
+int grib_accessor_class_library_version_t::value_count(grib_accessor* a, long* count)
+{
     *count = 1;
     return 0;
 }
 
-size_t grib_accessor_class_library_version_t::string_length(grib_accessor* a){
+size_t grib_accessor_class_library_version_t::string_length(grib_accessor* a)
+{
     return 255;
 }
