@@ -10,8 +10,6 @@
 
 /***************************************************************************
  *   Jean Baptiste Filippi - 01.11.2005                                    *
- *   Enrico Fucile
- *                                                                         *
  ***************************************************************************/
 #include "grib_api_internal.h"
 
@@ -35,7 +33,7 @@ static pthread_mutex_t mutex_hash_array = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t mutex_stream     = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t mutex_parse      = PTHREAD_MUTEX_INITIALIZER;
 
-static void init()
+static void init_mutex()
 {
     pthread_mutexattr_t attr;
     pthread_mutexattr_init(&attr);
@@ -57,7 +55,7 @@ static omp_nest_lock_t mutex_hash_array;
 static omp_nest_lock_t mutex_stream;
 static omp_nest_lock_t mutex_parse;
 
-static void init()
+static void init_mutex()
 {
     GRIB_OMP_CRITICAL(lock_grib_parse_utils_c)
     {
@@ -92,7 +90,7 @@ int grib_recompose_name(grib_handle* h, grib_accessor* observer, const char* una
     fname[0]     = 0;
     ptrEnd_fname = fname;
 
-    /* uname is a string like "grib[GRIBEditionNumber:l]/boot.def". The result fname will be grib2/boot.def */
+    /* uname is a string like "grib[GRIBEditionNumber:i]/boot.def". The result fname will be grib2/boot.def */
     while (uname[i] != '\0') {
         if (mode > -1) {
             if (uname[i] == ':') {
@@ -109,7 +107,7 @@ int grib_recompose_name(grib_handle* h, grib_accessor* observer, const char* una
                     }
                     else {
                         grib_context_log(h->context, GRIB_LOG_WARNING,
-                        "Recompose name: Problem recomposing filename with : %s ( %s no accessor found)", uname, loc);
+                          "%s: Problem recomposing filename with: %s (%s no accessor found)", __func__, uname, loc);
                         return GRIB_NOT_FOUND;
                     }
                 }
@@ -117,16 +115,16 @@ int grib_recompose_name(grib_handle* h, grib_accessor* observer, const char* una
                     switch (type) {
                         case GRIB_TYPE_STRING:
                             replen = 1024;
-                            ret    = grib_unpack_string(a, val, &replen);
+                            ret    = a->unpack_string(val, &replen);
                             break;
                         case GRIB_TYPE_DOUBLE:
                             replen = 1;
-                            ret    = grib_unpack_double(a, &dval, &replen);
+                            ret    = a->unpack_double(&dval, &replen);
                             snprintf(val, sizeof(val), "%.12g", dval);
                             break;
                         case GRIB_TYPE_LONG:
                             replen = 1;
-                            ret    = grib_unpack_long(a, &lval, &replen);
+                            ret    = a->unpack_long(&lval, &replen);
                             snprintf(val, sizeof(val), "%d", (int)lval);
                             break;
                         default:
@@ -158,15 +156,15 @@ int grib_recompose_name(grib_handle* h, grib_accessor* observer, const char* una
         else if (uname[i] == '[')
             mode = 0;
         else {
-#if 0
-            int llen=strlen(fname);  /* The strlen cost is too high */
-            fname[llen]=uname[i];
-            fname[llen+1]='\0';
-#else
-            /* Performance: faster to avoid call to strlen. Append to end */
+            // Old way: Slow; The strlen cost is too high
+            //int llen=strlen(fname);
+            //fname[llen]=uname[i];
+            //fname[llen+1]='\0';
+
+            // Faster to avoid call to strlen. Append to end
             *ptrEnd_fname++ = uname[i];
             *ptrEnd_fname   = '\0';
-#endif
+
             type = GRIB_TYPE_STRING;
         }
         i++;
@@ -175,134 +173,133 @@ int grib_recompose_name(grib_handle* h, grib_accessor* observer, const char* una
     return GRIB_SUCCESS;
 }
 
-#if 0
-int grib_accessor_print(grib_accessor* a, const char* name, int type, const char* format,
-                        const char* separator, int maxcols, int* newline, FILE* out)
-{
-    size_t size     = 0;
-    char* sval      = NULL;
-    char* p         = NULL;
-    double* dval    = 0;
-    long* lval      = 0;
-    char sbuf[1024] = {0,};
-    size_t replen            = 0;
-    int ret                  = 0;
-    char* myformat           = NULL;
-    char* myseparator        = NULL;
-    char double_format[]     = "%.12g"; /* default format for printing double keys */
-    char long_format[]       = "%ld";   /* default format for printing integer keys */
-    char default_separator[] = " ";
-    grib_handle* h           = grib_handle_of_accessor(a);
+// int grib_accessor_print(grib_accessor* a, const char* name, int type, const char* format,
+//                         const char* separator, int maxcols, int* newline, FILE* out)
+// {
+//     size_t size     = 0;
+//     char* sval      = NULL;
+//     char* p         = NULL;
+//     double* dval    = 0;
+//     long* lval      = 0;
+//     char sbuf[1024] = {0,};
+//     size_t replen            = 0;
+//     int ret                  = 0;
+//     char* myformat           = NULL;
+//     char* myseparator        = NULL;
+//     char double_format[]     = "%.12g"; /* default format for printing double keys */
+//     char long_format[]       = "%ld";   /* default format for printing integer keys */
+//     char default_separator[] = " ";
+//     grib_handle* h           = grib_handle_of_accessor(a);
 
-    if (type == -1)
-        type = grib_accessor_get_native_type(a);
-    switch (type) {
-        case GRIB_TYPE_STRING:
-            replen = sizeof(sbuf) / sizeof(*sbuf);
-            ret    = grib_unpack_string(a, sbuf, &replen);
-            fprintf(out, "%s", sbuf);
-            break;
-        case GRIB_TYPE_DOUBLE:
-            myformat    = format ? (char*)format : double_format;
-            myseparator = separator ? (char*)separator : default_separator;
-            if (name[0] == '/' || name[0] == '#') {
-                long count;
-                ret  = grib_value_count(a, &count);
-                size = count;
-            }
-            else {
-                ret = ecc__grib_get_size(h, a, &size);
-            }
-            if (ret) return ret;
-            dval = (double*)grib_context_malloc_clear(h->context, sizeof(double) * size);
-            if (name[0] == '/' || name[0] == '#') {
-                replen = size;
-                ret    = grib_unpack_double(a, dval, &replen);
-            }
-            else {
-                replen = 0;
-                ret    = ecc__grib_get_double_array_internal(h, a, dval, size, &replen);
-            }
-            if (replen == 1)
-                fprintf(out, myformat, dval[0]);
-            else {
-                int i    = 0;
-                int cols = 0;
-                for (i = 0; i < replen; i++) {
-                    *newline = 1;
-                    fprintf(out, myformat, dval[i]);
-                    if (i < replen - 1)
-                        fprintf(out, "%s", myseparator);
-                    cols++;
-                    if (cols >= maxcols) {
-                        fprintf(out, "\n");
-                        *newline = 1;
-                        cols     = 0;
-                    }
-                }
-            }
-            grib_context_free(h->context, dval);
-            break;
-        case GRIB_TYPE_LONG:
-            myformat    = format ? (char*)format : long_format;
-            myseparator = separator ? (char*)separator : default_separator;
-            if (name[0] == '/' || name[0] == '#') {
-                long count;
-                ret  = grib_value_count(a, &count);
-                size = count;
-            }
-            else {
-                ret = ecc__grib_get_size(h, a, &size);
-            }
-            if (ret) return ret;
-            lval = (long*)grib_context_malloc_clear(h->context, sizeof(long) * size);
-            if (name[0] == '/' || name[0] == '#') {
-                replen = size;
-                ret    = grib_unpack_long(a, lval, &replen);
-            }
-            else {
-                replen = 0;
-                ret    = ecc__grib_get_long_array_internal(h, a, lval, size, &replen);
-            }
-            if (replen == 1)
-                fprintf(out, myformat, lval[0]);
-            else {
-                int i    = 0;
-                int cols = 0;
-                for (i = 0; i < replen; i++) {
-                    *newline = 1;
-                    fprintf(out, myformat, lval[i]);
-                    if (i < replen - 1)
-                        fprintf(out, "%s", myseparator);
-                    cols++;
-                    if (cols >= maxcols) {
-                        fprintf(out, "\n");
-                        *newline = 1;
-                        cols     = 0;
-                    }
-                }
-            }
-            grib_context_free(h->context, lval);
-            break;
-        case GRIB_TYPE_BYTES:
-            replen = a->length;
-            sval   = (char*)grib_context_malloc(h->context, replen * sizeof(char));
-            ret    = grib_unpack_string(a, sval, &replen);
-            p      = sval;
-            while ((replen--) > 0)
-                fprintf(out, "%c", *(p++));
-            grib_context_free(h->context, sval);
-            *newline = 0;
-            break;
-        default:
-            grib_context_log(h->context, GRIB_LOG_WARNING, "grib_accessor_print: Problem to print \"%s\", invalid type %d", a->name, type);
-    }
-    return ret;
-}
-#endif
+//     if (type == -1)
+//         type = a->get_native_type();
+//     switch (type) {
+//         case GRIB_TYPE_STRING:
+//             replen = sizeof(sbuf) / sizeof(*sbuf);
+//             ret    = a->unpack_string(sbuf, &replen);
+//             fprintf(out, "%s", sbuf);
+//             break;
+//         case GRIB_TYPE_DOUBLE:
+//             myformat    = format ? (char*)format : double_format;
+//             myseparator = separator ? (char*)separator : default_separator;
+//             if (name[0] == '/' || name[0] == '#') {
+//                 long count;
+//                 ret  = a->value_count(&count);
+//                 size = count;
+//             }
+//             else {
+//                 ret = grib_get_size_(h, a, &size);
+//             }
+//             if (ret) return ret;
+//             dval = (double*)grib_context_malloc_clear(h->context, sizeof(double) * size);
+//             if (name[0] == '/' || name[0] == '#') {
+//                 replen = size;
+//                 ret    = a->unpack_double(dval, &replen);
+//             }
+//             else {
+//                 replen = 0;
+//                 ret    = ecc__grib_get_double_array_internal(h, a, dval, size, &replen);
+//             }
+//             if (replen == 1)
+//                 fprintf(out, myformat, dval[0]);
+//             else {
+//                 int i    = 0;
+//                 int cols = 0;
+//                 for (i = 0; i < replen; i++) {
+//                     *newline = 1;
+//                     fprintf(out, myformat, dval[i]);
+//                     if (i < replen - 1)
+//                         fprintf(out, "%s", myseparator);
+//                     cols++;
+//                     if (cols >= maxcols) {
+//                         fprintf(out, "\n");
+//                         *newline = 1;
+//                         cols     = 0;
+//                     }
+//                 }
+//             }
+//             grib_context_free(h->context, dval);
+//             break;
+//         case GRIB_TYPE_LONG:
+//             myformat    = format ? (char*)format : long_format;
+//             myseparator = separator ? (char*)separator : default_separator;
+//             if (name[0] == '/' || name[0] == '#') {
+//                 long count;
+//                 ret  = a->value_count(&count);
+//                 size = count;
+//             }
+//             else {
+//                 ret = grib_get_size_(h, a, &size);
+//             }
+//             if (ret) return ret;
+//             lval = (long*)grib_context_malloc_clear(h->context, sizeof(long) * size);
+//             if (name[0] == '/' || name[0] == '#') {
+//                 replen = size;
+//                 ret    = a->unpack_long(lval, &replen);
+//             }
+//             else {
+//                 replen = 0;
+//                 ret    = ecc__grib_get_long_array_internal(h, a, lval, size, &replen);
+//             }
+//             if (replen == 1)
+//                 fprintf(out, myformat, lval[0]);
+//             else {
+//                 int i    = 0;
+//                 int cols = 0;
+//                 for (i = 0; i < replen; i++) {
+//                     *newline = 1;
+//                     fprintf(out, myformat, lval[i]);
+//                     if (i < replen - 1)
+//                         fprintf(out, "%s", myseparator);
+//                     cols++;
+//                     if (cols >= maxcols) {
+//                         fprintf(out, "\n");
+//                         *newline = 1;
+//                         cols     = 0;
+//                     }
+//                 }
+//             }
+//             grib_context_free(h->context, lval);
+//             break;
+//         case GRIB_TYPE_BYTES:
+//             replen = a->length;
+//             sval   = (char*)grib_context_malloc(h->context, replen * sizeof(char));
+//             ret    = a->unpack_string(sval, &replen);
+//             p      = sval;
+//             while ((replen--) > 0)
+//                 fprintf(out, "%c", *(p++));
+//             grib_context_free(h->context, sval);
+//             *newline = 0;
+//             break;
+//         default:
+//             grib_context_log(h->context, GRIB_LOG_WARNING, "grib_accessor_print: Problem to print \"%s\", invalid type %d", a->name, type);
+//     }
+//     return ret;
+// }
 
 int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const char* name,
-                              int type, const char* format, const char* separator, int maxcols, int* newline, FILE* out)
+                              int type, const char* format, const char* separator, int equal,
+                              int maxcols, int* newline, FILE* out)
 {
     size_t size = 0, len = 0, replen = 0, j = 0;
     unsigned char* bval      = NULL;
@@ -316,22 +313,24 @@ int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const cha
     char long_format[]       = "%ld";   /* default format for printing integer keys */
     char default_separator[] = " ";
     grib_accessor* a         = al->accessor;
-    DebugAssert(a);
+    DEBUG_ASSERT(a);
 
     /* Number of columns specified as 0 means print on ONE line i.e. num cols = infinity */
     if (maxcols == 0)
         maxcols = INT_MAX;
 
+    if (equal) fprintf(out, "%s=", name); // ECC-1878
+
     if (type == -1)
-        type = grib_accessor_get_native_type(al->accessor);
-    grib_accessors_list_value_count(al, &size);
+        type = al->accessor->get_native_type();
+    al->value_count(&size);
     switch (type) {
         case GRIB_TYPE_STRING:
             myseparator = separator ? (char*)separator : default_separator;
             if (size == 1) {
                 char sbuf[1024] = {0,};
                 len = sizeof(sbuf);
-                ret = grib_unpack_string(al->accessor, sbuf, &len);
+                ret = al->accessor->unpack_string(sbuf, &len);
                 if (grib_is_missing_string(al->accessor, (unsigned char*)sbuf, len)) {
                     fprintf(out, "%s", "MISSING");
                 }
@@ -343,7 +342,7 @@ int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const cha
                 int cols = 0;
                 j = 0;
                 cvals    = (char**)grib_context_malloc_clear(h->context, sizeof(char*) * size);
-                grib_accessors_list_unpack_string(al, cvals, &size);
+                al->unpack_string(cvals, &size);
                 for (j = 0; j < size; j++) {
                     *newline = 1;
                     fprintf(out, "%s", cvals[j]);
@@ -364,7 +363,7 @@ int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const cha
             myformat    = format ? (char*)format : double_format;
             myseparator = separator ? (char*)separator : default_separator;
             dval        = (double*)grib_context_malloc_clear(h->context, sizeof(double) * size);
-            ret         = grib_accessors_list_unpack_double(al, dval, &size);
+            ret         = al->unpack_double(dval, &size);
             if (size == 1)
                 fprintf(out, myformat, dval[0]);
             else {
@@ -389,7 +388,7 @@ int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const cha
             myformat    = format ? (char*)format : long_format;
             myseparator = separator ? (char*)separator : default_separator;
             lval        = (long*)grib_context_malloc_clear(h->context, sizeof(long) * size);
-            ret         = grib_accessors_list_unpack_long(al, lval, &size);
+            ret         = al->unpack_long(lval, &size);
             if (size == 1)
                 fprintf(out, myformat, lval[0]);
             else {
@@ -413,7 +412,7 @@ int grib_accessors_list_print(grib_handle* h, grib_accessors_list* al, const cha
         case GRIB_TYPE_BYTES:
             replen = a->length;
             bval   = (unsigned char*)grib_context_malloc(h->context, replen * sizeof(unsigned char));
-            ret    = grib_unpack_bytes(al->accessor, bval, &replen);
+            ret    = al->accessor->unpack_bytes(bval, &replen);
             for (j = 0; j < replen; j++) {
                 fprintf(out, "%02x", bval[j]);
             }
@@ -438,6 +437,7 @@ int grib_recompose_print(grib_handle* h, grib_accessor* observer, const char* un
     char* format    = NULL;
     int type        = -1;
     char* separator = NULL;
+    int equal = 0; // See ECC-1878
     int l;
     char buff[10] = {0,};
     char buff1[1024] = {0,};
@@ -475,7 +475,8 @@ int grib_recompose_print(grib_handle* h, grib_accessor* observer, const char* un
                     break;
                 case '!':
                     pp = (char*)uname;
-                    if (string_to_long(uname + i + 1, &numcols) == GRIB_SUCCESS) {
+                    // Turn off strict as the input string will have a final ']' suffix
+                    if (string_to_long(uname + i + 1, &numcols, /*strict=*/0) == GRIB_SUCCESS) {
                         maxcols = (int)numcols;
                     }
                     else {
@@ -488,8 +489,10 @@ int grib_recompose_print(grib_handle* h, grib_accessor* observer, const char* un
                     i += pp - uname - i - 1;
                     break;
                 case ']':
-                    loc[mode] = 0;
-                    mode      = -1;
+                    // ECC-1878: The '=' format specifier
+                    if (loc[mode - 1] == '=') { loc[mode-1] = 0; equal = 1; }
+                    else                      { loc[mode] = 0; }
+                    mode = -1;
                     if (al) grib_accessors_list_delete(h->context, al);
                     al        = grib_find_accessors_list(h, loc); /* This allocates memory */
                     if (!al) {
@@ -504,7 +507,7 @@ int grib_recompose_print(grib_handle* h, grib_accessor* observer, const char* un
                         }
                     }
                     else {
-                        ret = grib_accessors_list_print(h, al, loc, type, format, separator, maxcols, &newline, out);
+                        ret = grib_accessors_list_print(h, al, loc, type, format, separator, equal, maxcols, &newline, out);
 
                         if (ret != GRIB_SUCCESS) {
                             /* grib_context_log(h->context, GRIB_LOG_ERROR,"grib_recompose_print: Could not recompose print : %s", uname); */
@@ -712,7 +715,7 @@ extern int grib_yyparse(void);
 static int parse(grib_context* gc, const char* filename)
 {
     int err = 0;
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
+    GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex_parse);
 
 #ifdef YYDEBUG
@@ -747,19 +750,19 @@ static int parse(grib_context* gc, const char* filename)
 
 static grib_action* grib_parse_stream(grib_context* gc, const char* filename)
 {
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
+    GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex_stream);
 
     grib_parser_all_actions = 0;
 
     if (parse(gc, filename) == 0) {
         if (grib_parser_all_actions) {
-            GRIB_MUTEX_UNLOCK(&mutex_stream)
+            GRIB_MUTEX_UNLOCK(&mutex_stream);
             return grib_parser_all_actions;
         }
         else {
             grib_action* ret = grib_action_create_noop(gc, filename);
-            GRIB_MUTEX_UNLOCK(&mutex_stream)
+            GRIB_MUTEX_UNLOCK(&mutex_stream);
             return ret;
         }
     }
@@ -771,7 +774,7 @@ static grib_action* grib_parse_stream(grib_context* gc, const char* filename)
 
 grib_concept_value* grib_parse_concept_file(grib_context* gc, const char* filename)
 {
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
+    GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex_file);
 
     gc                  = gc ? gc : grib_context_get_default();
@@ -789,7 +792,7 @@ grib_concept_value* grib_parse_concept_file(grib_context* gc, const char* filena
 
 grib_hash_array_value* grib_parse_hash_array_file(grib_context* gc, const char* filename)
 {
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
+    GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex_file);
 
     gc                  = gc ? gc : grib_context_get_default();
@@ -805,32 +808,28 @@ grib_hash_array_value* grib_parse_hash_array_file(grib_context* gc, const char*
     }
 }
 
-grib_rule* grib_parse_rules_file(grib_context* gc, const char* filename)
-{
-    if (!gc)
-        gc = grib_context_get_default();
-
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
-    GRIB_MUTEX_LOCK(&mutex_rules);
-
-    gc                  = gc ? gc : grib_context_get_default();
-    grib_parser_context = gc;
-
-    if (parse(gc, filename) == 0) {
-        GRIB_MUTEX_UNLOCK(&mutex_rules);
-        return grib_parser_rules;
-    }
-    else {
-        GRIB_MUTEX_UNLOCK(&mutex_rules);
-        return NULL;
-    }
-}
+// grib_rule* grib_parse_rules_file(grib_context* gc, const char* filename)
+// {
+//     if (!gc) gc = grib_context_get_default();
+//     GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
+//     GRIB_MUTEX_LOCK(&mutex_rules);
+//     gc                  = gc ? gc : grib_context_get_default();
+//     grib_parser_context = gc;
+//     if (parse(gc, filename) == 0) {
+//         GRIB_MUTEX_UNLOCK(&mutex_rules);
+//         return grib_parser_rules;
+//     }
+//     else {
+//         GRIB_MUTEX_UNLOCK(&mutex_rules);
+//         return NULL;
+//     }
+// }
 
 grib_action* grib_parse_file(grib_context* gc, const char* filename)
 {
     grib_action_file* af;
 
-    GRIB_MUTEX_INIT_ONCE(&once, &init);
+    GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex_file);
 
     af = 0;
@@ -877,19 +876,14 @@ int grib_type_to_int(char id)
     switch (id) {
         case 'd':
             return GRIB_TYPE_DOUBLE;
-            break;
         case 'f':
             return GRIB_TYPE_DOUBLE;
-            break;
         case 'l':
             return GRIB_TYPE_LONG;
-            break;
         case 'i':
             return GRIB_TYPE_LONG;
-            break;
         case 's':
             return GRIB_TYPE_STRING;
-            break;
     }
     return GRIB_TYPE_UNDEFINED;
 }
