@@ -8,7 +8,7 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
 REDIRECT=/dev/null
 
@@ -50,13 +50,15 @@ do
 
 done
 
-echo "ECC-457 ECMWF total precipitation..."
-# -----------------------------------------
+echo "ECC-457,ECC-1298 ECMWF total precipitation..."
+# ---------------------------------------------------
 input=${data_dir}/tp_ecmwf.grib
 output=temp.grib1to2.grib
 ${tools_dir}/grib_set -s edition=2 $input $output
 res=`${tools_dir}/grib_get -w count=1 -p edition,paramId,units $output`
-[ "$res" = "2 228228 kg m**-2" ]
+[ "$res" = "2 228 m" ]
+res=`${tools_dir}/grib_get -w count=1 -p stepType $output`
+[ "$res" = "accum" ]
 rm -f $output
 
 
@@ -80,13 +82,45 @@ if [ -x "${tools_dir}/grib_check_gaussian_grid" ]; then
     ${tools_dir}/grib_check_gaussian_grid $input $output
 fi
 
-#sed "s:toolsdir:${tools_dir}/:" ${tools_dir}/grib1to2.txt > ${tools_dir}/grib1to2.test
-#chmod +x ${tools_dir}/grib1to2.test
-#${tools_dir}/grib1to2.test -f ${data_dir}/test.grib1 ${data_dir}/test.grib2
-#${tools_dir}/grib_get -p typeOfProcessedData:s,type:s ${data_dir}/test.grib2 > ${data_dir}/typeOfProcessedData.log
 
-#diff ${data_dir}/typeOfProcessedData.log ${data_dir}/typeOfProcessedData.ok
+echo "ECC-811 Check shapeOfTheEarth..."
+# ---------------------------------------------------
+sample_g1=$ECCODES_SAMPLES_PATH/GRIB1.tmpl
+${tools_dir}/grib_set -s edition=2 $sample_g1 $output
+grib_check_key_equals $sample_g1 shapeOfTheEarth 0
+grib_check_key_equals $output    shapeOfTheEarth 0
 
-#${tools_dir}/grib_compare -Pe ${data_dir}/test.grib1 ${data_dir}/test.grib2
 
-#rm -f ${data_dir}/test.grib2
+echo "ECC-1329: Cannot convert runoff (paramId=205)"
+# --------------------------------------------------------
+temp1="temp1.grib1to2.grib1"
+temp2="temp2.grib1to2.grib2"
+${tools_dir}/grib_set -s paramId=205,P1=240,marsType=fc $sample_g1 $temp1
+${tools_dir}/grib_set -s edition=2 $temp1 $temp2
+grib_check_key_equals $temp2 discipline,stepType,shortName,paramId '2 accum ro 205'
+# Fix the stepRange too - TODO
+${tools_dir}/grib_set -s edition=2,startStep=0 $temp1 $temp2
+grib_check_key_equals $temp2 stepType,stepRange 'accum 0-240'
+rm -f $temp1 $temp2
+
+echo "ECC-1646: Cannot convert sro, uvb, lsp, e, and pev"
+# --------------------------------------------------------
+for sn in e lsp pev sro uvb; do
+    ${tools_dir}/grib_set -s shortName=$sn,typeOfLevel=surface,level=0 $sample_g1 $temp1
+    ${tools_dir}/grib_set -s edition=2 $temp1 $temp2
+    ${tools_dir}/grib_compare -e -b param $temp1 $temp2
+done
+
+# Turn on (brief) DEBUGGING messages
+sample_g1=$ECCODES_SAMPLES_PATH/GRIB1.tmpl
+output=temp.grib1to2.grib
+ECCODES_DEBUG=-1 ${tools_dir}/grib_set -s edition=2 $sample_g1 $output
+
+# -G option
+sample_g1=$ECCODES_SAMPLES_PATH/GRIB1.tmpl
+${tools_dir}/grib_set -G -s edition=2 $sample_g1 $temp2
+
+
+# Clean up
+rm -f $output
+rm -f $temp1 $temp2
